@@ -12,16 +12,15 @@ struct Return {
 struct Runner;
 
 #[async_trait::async_trait]
-impl lambda_runtime_types::Runner<(), Event, Return> for Runner {
-    async fn run<'a>(
+impl<'a> lambda_runtime_types::Runner<'a, (), Event, Return> for Runner {
+    async fn run(
         _shared: &'a (),
-        event: Event,
-        _region: &'a str,
-        _ctx: lambda_runtime::Context,
+        event: lambda_runtime_types::LambdaEvent<'a, Event>,
     ) -> anyhow::Result<Return> {
         log::info!("{:?}", event);
         Ok(Return {
             data: event
+                .event
                 .attributes
                 .get("test")
                 .and_then(|a| a.as_str())
@@ -31,7 +30,7 @@ impl lambda_runtime_types::Runner<(), Event, Return> for Runner {
         })
     }
 
-    async fn setup() -> anyhow::Result<()> {
+    async fn setup(_region: &'a str) -> anyhow::Result<()> {
         simple_logger::SimpleLogger::new()
             .with_level(log::LevelFilter::Info)
             .init()
